abacusai.api_class.project — AbacusAI documentation

# `abacusai.api_class.project`

## Module Contents

### Classes

`FeatureMappingConfig` | Feature mapping configuration for a feature group type.
`ProjectFeatureGroupTypeMappingsConfig` | Project feature group type mappings.

class abacusai.api_class.project.FeatureMappingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Feature mapping configuration for a feature group type.

  Parameters:

    - feature_name (str) – The name of the feature in the feature group.

    - feature_mapping (str) – The desired feature mapping for the feature.

    - nested_feature_name (str) – The name of the nested feature in the feature group.

  feature_name: str
  feature_mapping: str
  nested_feature_name: str

class abacusai.api_class.project.ProjectFeatureGroupTypeMappingsConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Project feature group type mappings.

  Parameters:

    - feature_group_id (str) – The unique identifier for the feature group.

    - feature_group_type (str) – The feature group type.

    - feature_mappings (List[FeatureMappingConfig]) – The feature mappings for the feature group.

  feature_group_id: str
  feature_group_type: str
  feature_mappings: List[FeatureMappingConfig]
  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –